@@ -199,7 +199,8 @@ class SendGrid(object):
 
     def add_schedule(self, newsletter_name, at=None, after=None):
         if at:
-            d = dict(name=newsletter_name, at=at.isoformat() + "+00:00")
+            print "time ", at.isoformat()
+            d = dict(name=newsletter_name, at=at.isoformat())
         elif after:
             d = dict(name=newsletter_name, after=after)
         else:
